Test Comments

Here we demonstrate how comments can be interspersed within Selenium tests.

Test Comments
open | ../tests/html/test_verifications.html?foo=bar |
Any row with fewer than 3 cells is ignored
verifyLocation | */tests/html/test_verifications.html* |  | anything after the 3rd cell is ignored
verifyValue | theText | the text value

- Multiple test-tables may occur.
- Any text/markup outside of tables is ignored.

verifyValue | theHidden | the hidden value
verifyText | theSpan | this is the span